# -*- coding: utf-8 -*-
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.

class Key(object):
    def __init__(self, *names): ...
    @property
    def name(self): ...
    def __hash__(self): ...
    def __repr__(self): ...
    def __eq__(self, other): ...

SHIFT = ...
CONTROL = ...
ALT = ...
META = ...  # That Mac thingy

UP = ...
DOWN = ...
LEFT = ...
RIGHT = ...
PAGEUP = ...
PAGEDOWN = ...

INSERT = ...
DELETE = ...
HOME = ...
END = ...

ESCAPE = ...
BACKSPACE = ...

F1 = ...
F2 = ...
F3 = ...
F4 = ...
F5 = ...
F6 = ...
F7 = ...
F8 = ...
F9 = ...
F10 = ...
F11 = ...
F12 = ...

SPACE = ...
ENTER = ...
TAB = ...
