from ..gloo.texture import Texture2D

# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.
# -----------------------------------------------------------------------------

from .wrappers import read_pixels

def _screenshot(viewport=None, alpha=True): ...

KEYWORDS = ...

def check_variable(name): ...
def check_identifier(name): ...
def check_enum(enum, name=None, valid=None): ...

vert_draw: str = ...

frag_draw: str = ...

def draw_texture(tex: Texture2D): ...
