PY37 = ...
PY38 = ...
PYPY = ...

def set_function_name(f, name, cls): ...
def is_platform_little_endian() -> bool: ...
def is_platform_windows() -> bool: ...
def is_platform_linux() -> bool: ...
def is_platform_mac() -> bool: ...
def is_platform_32bit() -> bool: ...
