# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.
# -----------------------------------------------------------------------------

__all__ = ["list_fonts"]

from ._triage import (
    list_fonts as list_fonts,
)  # noqa, analysis:ignore
from ._vispy_fonts import _vispy_fonts as _vispy_fonts  # noqa, analysis:ignore
