from .font_manager import FontProperties

family_punc = ...
family_unescape = ...
family_escape = ...
value_punc = ...
value_unescape = ...
value_escape = ...

class FontconfigPatternParser:
    def __init__(self) -> None: ...
    def parse(self, pattern: str) -> dict[str, list[str]]: ...

parse_fontconfig_pattern = ...

def generate_fontconfig_pattern(d: FontProperties) -> str: ...
