import sys

from packaging import version as _version

def ensure_python_version(min_version): ...
def _check_version(actver, version, cmp_op): ...
def get_module_version(module_name): ...
def is_installed(name: str, version: str | None = None) -> bool: ...
def require(name: str, version: str | None = None): ...
def get_module(module_name: str, version: str | None = None): ...
