from ..utils import groups

class UnionFind:
    def __init__(self, elements=None): ...
    def __getitem__(self, object): ...
    def __iter__(self): ...
    def to_sets(self): ...
    def union(self, *objects): ...
