"""
This type stub file was generated by pyright.
"""

"""Support for interactive macros in IPython"""
coding_declaration = ...
class Macro:
    """Simple class to store the value of macros as strings.

    Macro is just a callable that executes a string of IPython
    input when called.
    """
    def __init__(self, code) -> None:
        """store the macro value, as a single string which can be executed"""
        ...
    
    def __str__(self) -> str:
        ...
    
    def __repr__(self):
        ...
    
    def __getstate__(self):
        """ needed for safe pickling via %store """
        ...
    
    def __add__(self, other): # -> Macro:
        ...
    


