# -*- coding: utf-8 -*-
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.

import numpy as np

class DashAtlas(object):
    def __init__(self, shape=...): ...
    def __getitem__(self, key): ...
    def __setitem__(self, key, value): ...
    def make_pattern(self, pattern, caps=[1, 1]): ...
