latex_to_bakoma: dict[str, tuple] = ...
type12uni: dict[str, int] = ...
uni2type1: dict[str, int] = ...
tex2uni: dict[str, int] = ...
stix_virtual_fonts: dict[str, dict[str, list[tuple]]] = ...
stix_glyph_fixes: dict[int, int] = ...
