"""
This type stub file was generated by pyright.
"""

from traitlets.config import Configurable

"""
Color managing related utilities
"""
available_themes = ...
class Colorable(Configurable):
    """
    A subclass of configurable for all the classes that have a `default_scheme`
    """
    default_style = ...


