from ...classes.graph import Graph

__all__ = ["is_arborescence", "is_branching", "is_forest", "is_tree"]

def is_arborescence(G: Graph) -> bool: ...
def is_branching(G: Graph) -> bool: ...
def is_forest(G: Graph) -> bool: ...
def is_tree(G: Graph) -> bool: ...
