# -*- coding: utf-8 -*-
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.

import time as systime

# get a reference starting time - initial performance counter
START_TIME = ...

def time(): ...
