"""
This type stub file was generated by pyright.
"""

"""Usage information for the main IPython applications.
"""
cl_usage = ...
interactive_usage = ...
interactive_usage_min = ...
quick_reference = ...
default_banner_parts = ...
default_banner = ...
