def radd(left, right): ...
def rsub(left, right): ...
def rmul(left, right): ...
def rdiv(left, right): ...
def rtruediv(left, right): ...
def rfloordiv(left, right): ...
def rmod(left, right): ...
def rdivmod(left, right): ...
def rpow(left, right): ...
def rand_(left, right): ...
def ror_(left, right): ...
def rxor(left, right): ...
