import pickle as pkl

def load_reduce(self) -> None: ...
def load_newobj(self) -> None: ...
def load_newobj_ex(self) -> None: ...
def load(fh, encoding: str | None = ..., is_verbose: bool = ...): ...
