"""
This type stub file was generated by pyright.
"""

import importlib
import os

aliases = ...
backends = ...
registered = ...
def register(name, inputhook): # -> None:
    """Register the function *inputhook* as an event loop integration."""
    ...

class UnknownBackend(KeyError):
    def __init__(self, name) -> None:
        ...
    
    def __str__(self) -> str:
        ...
    


def set_qt_api(gui): # -> None:
    """Sets the `QT_API` environment variable if it isn't already set."""
    ...

def get_inputhook_name_and_func(gui):
    ...

