# -*- coding: utf-8 -*-
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.

from .line import LineVisual as LineVisual  # noqa
from .arrow import ArrowVisual as ArrowVisual  # noqa
