from collections import defaultdict
from ...classes.graph import Graph

__all__ = ["equitable_color"]

def is_coloring(G: Graph, coloring): ...
def is_equitable(G: Graph, coloring, num_colors=None): ...
def make_C_from_F(F): ...
def make_N_from_L_C(L, C): ...
def make_H_from_C_N(C, N): ...
def change_color(u, X, Y, N, H, F, C, L): ...
def move_witnesses(src_color, dst_color, N, H, F, C, T_cal, L): ...
def pad_graph(G: Graph, num_colors): ...
def procedure_P(V_minus, V_plus, N, H, F, C, L, excluded_colors=None): ...
def equitable_color(G: Graph, num_colors): ...
