# -*- coding: utf-8 -*-
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.
__all__ = [
    "AxisWidget",
    "Console",
    "ColorBarWidget",
    "Grid",
    "Label",
    "ViewBox",
    "Widget",
]

from .console import Console as Console  # noqa
from .grid import Grid as Grid  # noqa
from .viewbox import ViewBox as ViewBox  # noqa
from .widget import Widget as Widget  # noqa
from .axis import AxisWidget as AxisWidget  # noqa
from .colorbar import ColorBarWidget as ColorBarWidget  # noqa
from .label import Label as Label  # noqa
