# Python: 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# Library: scipy, version: 1.6.2
# Module: scipy.integrate._odepack, version:  1.9 
import typing
import builtins as _mod_builtins
import odepack as _mod_odepack

__doc__: typing.Any
__file__: str
__name__: str
__package__: str
__version__: str
error = _mod_odepack.error
def odeint(fun, y0, t, args=..., Dfun=..., col_deriv=..., ml=..., mu=..., full_output=..., rtol=..., atol=..., tcrit=..., h0=..., hmax=..., hmin=..., ixpr=..., mxstep=..., mxhnil=..., mxordn=..., mxords=...) -> typing.Any:
    '[y,{infodict,}istate] = odeint(fun, y0, t, args=(), Dfun=None, col_deriv=0, ml=, mu=, full_output=0, rtol=, atol=, tcrit=, h0=0.0, hmax=0.0, hmin=0.0, ixpr=0.0, mxstep=0.0, mxhnil=0, mxordn=0, mxords=0)\n  yprime = fun(y,t,...)'
    ...

def __getattr__(name) -> typing.Any:
    ...

