# -*- coding: utf-8 -*-
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.

from .fig import Fig as Fig  # noqa
from .plotwidget import PlotWidget as PlotWidget  # noqa
from ..scene import *  # noqa
