
# This file is generated by docs2stub. These types are intended
# to simplify the stubs generated by docs2stub. They are not
# intended to be used directly by other users.

import decimal
import io
import numpy.typing
import numpy as np
import pandas as pd
from .base import BaseEstimator, ClassifierMixin, RegressorMixin
from scipy.sparse import spmatrix



Decimal = decimal.Decimal
PythonScalar = str | int | float | bool

ArrayLike = numpy.typing.ArrayLike
MatrixLike = np.ndarray | pd.DataFrame | spmatrix
FileLike = io.IOBase
PathLike = str
Int = int | np.int8 | np.int16 | np.int32 | np.int64
Float = float | np.float16 | np.float32 | np.float64

PandasScalar = pd.Period | pd.Timestamp | pd.Timedelta | pd.Interval
Scalar = PythonScalar | PandasScalar

Estimator = BaseEstimator
Classifier = ClassifierMixin
Regressor = RegressorMixin

Color = tuple[float, float, float] | str

        