from typing import IO

from pandas.io.formats.format import (
    DataFrameFormatter as DataFrameFormatter,
    TableFormatter as TableFormatter,
)

class LatexFormatter(TableFormatter):
    fmt = ...
    frame = ...
    bold_rows = ...
    column_format = ...
    longtable = ...
    multicolumn = ...
    multicolumn_format = ...
    multirow = ...
    caption = ...
    label = ...
    escape = ...
    def __init__(
        self,
        formatter: DataFrameFormatter,
        column_format: str | None = ...,
        longtable: bool = ...,
        multicolumn: bool = ...,
        multicolumn_format: str | None = ...,
        multirow: bool = ...,
        caption: str | None = ...,
        label: str | None = ...,
    ) -> None: ...
    clinebuf = ...
    def write_result(self, buf: IO[str]) -> None: ...
