from typing import Any

from django.db import models

class FlatPage(models.Model):
    url: models.CharField[Any] = ...
    title: models.CharField[Any] = ...
    content: models.TextField[Any] = ...
    enable_comments: models.BooleanField[Any] = ...
    template_name: models.CharField[Any] = ...
    registration_required: models.BooleanField[Any] = ...
    sites: models.ManyToManyField[Any, Any] = ...
    def get_absolute_url(self) -> str: ...
