import numpy as np
from scipy.special import ellipkinc as ellip_F, ellipeinc as ellip_E

def ellipsoid(a: float, b: float, c: float, spacing=..., levelset: bool = False): ...
def ellipsoid_stats(a: float, b: float, c: float) -> tuple[float, float]: ...
