# Python: 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# Library: scipy, version: 1.6.2
# Module: scipy.linalg.cython_blas, version: unspecified
import typing
import builtins as _mod_builtins

__doc__: str
__file__: str
__name__: str
__package__: str
__pyx_capi__: dict
def __pyx_unpickle_Enum() -> typing.Any:
    ...

__test__: dict
def _test_cdotc() -> typing.Any:
    ...

def _test_cdotu() -> typing.Any:
    ...

def _test_dasum() -> typing.Any:
    ...

def _test_ddot() -> typing.Any:
    ...

def _test_dgemm() -> typing.Any:
    ...

def _test_dnrm2() -> typing.Any:
    ...

def _test_dzasum() -> typing.Any:
    ...

def _test_dznrm2() -> typing.Any:
    ...

def _test_icamax() -> typing.Any:
    ...

def _test_idamax() -> typing.Any:
    ...

def _test_isamax() -> typing.Any:
    ...

def _test_izamax() -> typing.Any:
    ...

def _test_sasum() -> typing.Any:
    ...

def _test_scasum() -> typing.Any:
    ...

def _test_scnrm2() -> typing.Any:
    ...

def _test_sdot() -> typing.Any:
    ...

def _test_snrm2() -> typing.Any:
    ...

def _test_zdotc() -> typing.Any:
    ...

def _test_zdotu() -> typing.Any:
    ...

def __getattr__(name) -> typing.Any:
    ...

