from ._gaussian_mixture import GaussianMixture as GaussianMixture
from ._bayesian_mixture import BayesianGaussianMixture as BayesianGaussianMixture


__all__ = ["GaussianMixture", "BayesianGaussianMixture"]
