version: "1"

ignore:
  # The defaults
  - ".git"
  - "venv"
  - ".venv"
  - "env"
  - ".env"
  - ".tox"
  - "node_modules"
  - "vendor"
  # Extras
  - ".*"

rule_settings:
  python_version: "{{ python_version }}"
  enable: ["default"]
  disable:
    - "move-assign" # False positives
    - "remove-redundant-constructor-in-dict-union" # Explicit dict(zip(...)) is better
    - "no-conditionals-in-tests" # Not a great heuristic
