from numpy.typing import ArrayLike

# -*- coding: utf-8 -*-
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.

import numpy as np
from os import path as op

from ..util import load_data_file as load_data_file

# This is the package data dir, not the dir for config, etc.
DATA_DIR = ...

def load_iris() -> dict[str, np.ndarray]: ...
def load_crate() -> np.ndarray: ...
def pack_unit(value) -> np.ndarray: ...
def pack_ieee(value) -> np.ndarray: ...
def load_spatial_filters(packed: bool = True) -> tuple[np.ndarray, tuple[str, ...]]: ...
