# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# Copyright (c) 2014, Nicolas P. Rougier
# Distributed under the (new) BSD License. See LICENSE.txt for more info.
# -----------------------------------------------------------------------------

from itertools import product
from string import hexdigits

# See <http://www.w3.org/TR/SVG/types.html#ColorKeywords>
_keyword_colors: dict = ...

_HEXDEC: dict = ...

def _rgb(triplet): ...

class Color(object):
    def __init__(self, content): ...
    @property
    def rgb(self): ...
    @property
    def rgba(self): ...
    def __repr__(self): ...
