from ._label_propagation import (
    LabelPropagation as LabelPropagation,
    LabelSpreading as LabelSpreading,
)
from ._self_training import SelfTrainingClassifier as SelfTrainingClassifier

__all__ = ["SelfTrainingClassifier", "LabelPropagation", "LabelSpreading"]
