# Python: 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# Library: scipy, version: 1.6.2
# Module: scipy.sparse._sparsetools, version: unspecified
import typing
import builtins as _mod_builtins

__doc__: typing.Any
__file__: str
__name__: str
__package__: str
def bsr_diagonal() -> typing.Any:
    ...

def bsr_eldiv_bsr() -> typing.Any:
    ...

def bsr_elmul_bsr() -> typing.Any:
    ...

def bsr_ge_bsr() -> typing.Any:
    ...

def bsr_gt_bsr() -> typing.Any:
    ...

def bsr_le_bsr() -> typing.Any:
    ...

def bsr_lt_bsr() -> typing.Any:
    ...

def bsr_matmat() -> typing.Any:
    ...

def bsr_matvec() -> typing.Any:
    ...

def bsr_matvecs() -> typing.Any:
    ...

def bsr_maximum_bsr() -> typing.Any:
    ...

def bsr_minimum_bsr() -> typing.Any:
    ...

def bsr_minus_bsr() -> typing.Any:
    ...

def bsr_ne_bsr() -> typing.Any:
    ...

def bsr_plus_bsr() -> typing.Any:
    ...

def bsr_scale_columns() -> typing.Any:
    ...

def bsr_scale_rows() -> typing.Any:
    ...

def bsr_sort_indices() -> typing.Any:
    ...

def bsr_tocsr() -> typing.Any:
    ...

def bsr_transpose() -> typing.Any:
    ...

def coo_matvec() -> typing.Any:
    ...

def coo_tocsr() -> typing.Any:
    ...

def coo_todense() -> typing.Any:
    ...

def cs_graph_components() -> typing.Any:
    ...

def csc_diagonal() -> typing.Any:
    ...

def csc_eldiv_csc() -> typing.Any:
    ...

def csc_elmul_csc() -> typing.Any:
    ...

def csc_ge_csc() -> typing.Any:
    ...

def csc_gt_csc() -> typing.Any:
    ...

def csc_le_csc() -> typing.Any:
    ...

def csc_lt_csc() -> typing.Any:
    ...

def csc_matmat() -> typing.Any:
    ...

def csc_matmat_maxnnz() -> typing.Any:
    ...

def csc_matvec() -> typing.Any:
    ...

def csc_matvecs() -> typing.Any:
    ...

def csc_maximum_csc() -> typing.Any:
    ...

def csc_minimum_csc() -> typing.Any:
    ...

def csc_minus_csc() -> typing.Any:
    ...

def csc_ne_csc() -> typing.Any:
    ...

def csc_plus_csc() -> typing.Any:
    ...

def csc_tocsr() -> typing.Any:
    ...

def csr_column_index1() -> typing.Any:
    ...

def csr_column_index2() -> typing.Any:
    ...

def csr_count_blocks() -> typing.Any:
    ...

def csr_diagonal() -> typing.Any:
    ...

def csr_eldiv_csr() -> typing.Any:
    ...

def csr_eliminate_zeros() -> typing.Any:
    ...

def csr_elmul_csr() -> typing.Any:
    ...

def csr_ge_csr() -> typing.Any:
    ...

def csr_gt_csr() -> typing.Any:
    ...

def csr_has_canonical_format() -> typing.Any:
    ...

def csr_has_sorted_indices() -> typing.Any:
    ...

def csr_le_csr() -> typing.Any:
    ...

def csr_lt_csr() -> typing.Any:
    ...

def csr_matmat() -> typing.Any:
    ...

def csr_matmat_maxnnz() -> typing.Any:
    ...

def csr_matvec() -> typing.Any:
    ...

def csr_matvecs() -> typing.Any:
    ...

def csr_maximum_csr() -> typing.Any:
    ...

def csr_minimum_csr() -> typing.Any:
    ...

def csr_minus_csr() -> typing.Any:
    ...

def csr_ne_csr() -> typing.Any:
    ...

def csr_plus_csr() -> typing.Any:
    ...

def csr_row_index() -> typing.Any:
    ...

def csr_row_slice() -> typing.Any:
    ...

def csr_sample_offsets() -> typing.Any:
    ...

def csr_sample_values() -> typing.Any:
    ...

def csr_scale_columns() -> typing.Any:
    ...

def csr_scale_rows() -> typing.Any:
    ...

def csr_sort_indices() -> typing.Any:
    ...

def csr_sum_duplicates() -> typing.Any:
    ...

def csr_tobsr() -> typing.Any:
    ...

def csr_tocsc() -> typing.Any:
    ...

def csr_todense() -> typing.Any:
    ...

def dia_matvec() -> typing.Any:
    ...

def expandptr() -> typing.Any:
    ...

def get_csr_submatrix() -> typing.Any:
    ...

def test_throw_error() -> typing.Any:
    ...

def __getattr__(name) -> typing.Any:
    ...

