from numpy.typing import NDArray
import numpy as np
from scipy import ndimage as ndi

from .. import draw
from .._shared.utils import deprecate_kwarg

def square(width: int, dtype=...) -> NDArray: ...
@deprecate_kwarg(
    {"height": "ncols", "width": "nrows"},
    deprecated_version="0.18.0",
    removed_version="0.20.0",
)
def rectangle(nrows: int, ncols: int, dtype=...) -> NDArray: ...
def diamond(radius: int, dtype=...) -> NDArray: ...
def disk(radius: int, dtype=...) -> NDArray: ...
def ellipse(width: int, height: int, dtype=...) -> NDArray: ...
def cube(width: int, dtype=...) -> NDArray: ...
def octahedron(radius: int, dtype=...) -> NDArray: ...
def ball(radius: int, dtype=...) -> NDArray: ...
def octagon(m: int, n: int, dtype=...) -> NDArray: ...
def star(a: int, dtype=...) -> NDArray: ...
def _default_footprint(ndim): ...
