# -*- coding: utf-8 -*-
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.
from .shader_object import ShaderObject

class Expression(ShaderObject):
    def definition(self, names, version): ...

class TextExpression(Expression):
    def __init__(self, text): ...
    def __repr__(self): ...
    def expression(self, names=None): ...
    @property
    def text(self): ...
    @text.setter
    def text(self, t): ...
    def __eq__(self, a): ...
    def __hash__(self): ...

class FunctionCall(Expression):
    def __init__(self, function, args): ...
    def __repr__(self): ...
    @property
    def function(self): ...
    @property
    def dtype(self): ...
    def expression(self, names): ...
