import warnings
from collections import OrderedDict

from .digraph import DiGraph
from .graph import Graph
from .multidigraph import MultiDiGraph
from .multigraph import MultiGraph

__all__ = []

class OrderedGraph(Graph):

    node_dict_factory = ...
    adjlist_outer_dict_factory = ...
    adjlist_inner_dict_factory = ...
    edge_attr_dict_factory = ...

    def __init__(self, incoming_graph_data=None, **attr): ...

class OrderedDiGraph(DiGraph):

    node_dict_factory = ...
    adjlist_outer_dict_factory = ...
    adjlist_inner_dict_factory = ...
    edge_attr_dict_factory = ...

    def __init__(self, incoming_graph_data=None, **attr): ...

class OrderedMultiGraph(MultiGraph):

    node_dict_factory = ...
    adjlist_outer_dict_factory = ...
    adjlist_inner_dict_factory = ...
    edge_key_dict_factory = ...
    edge_attr_dict_factory = ...

    def __init__(self, incoming_graph_data=None, **attr): ...

class OrderedMultiDiGraph(MultiDiGraph):

    node_dict_factory = ...
    adjlist_outer_dict_factory = ...
    adjlist_inner_dict_factory = ...
    edge_key_dict_factory = ...
    edge_attr_dict_factory = ...

    def __init__(self, incoming_graph_data=None, **attr): ...
