"""
This type stub file was generated by pyright.
"""

""" Utilities for accessing the platform's clipboard.
"""
class ClipboardEmpty(ValueError):
    ...


def win32_clipboard_get():
    """ Get the current clipboard's text on Windows.

    Requires Mark Hammond's pywin32 extensions.
    """
    ...

def osx_clipboard_get() -> str:
    """ Get the clipboard's text on OS X.
    """
    ...

def tkinter_clipboard_get():
    """ Get the clipboard's text using Tkinter.

    This is the default on systems that are not Windows or OS X. It may
    interfere with other UI toolkits and should be replaced with an
    implementation that uses that toolkit.
    """
    ...

def wayland_clipboard_get():
    """Get the clipboard's text under Wayland using wl-paste command.

    This requires Wayland and wl-clipboard installed and running.
    """
    ...

