from typing import Any, Optional, Sequence

from django.apps.config import AppConfig

E001: Any

def check_async_unsafe(
    app_configs: Optional[Sequence[AppConfig]] = ..., **kwargs: Any
) -> Any: ...
