from os import PathLike
import numpy as np
import shutil
from packaging import version

from ._registry import registry, legacy_registry, registry_urls

from .. import __version__

import os.path as osp
import os

legacy_data_dir = ...
skimage_distribution_dir = ...

def _has_hash(path, expected_hash): ...
def create_image_fetcher(): ...

image_fetcher, data_dir = ...

def _skip_pytest_case_requiring_pooch(data_filename): ...
def _fetch(data_filename): ...
def _init_pooch(): ...
def download_all(directory: PathLike | None = None): ...
def lbp_frontal_face_cascade_filename(): ...
def _load(f, as_gray=False): ...
def camera(): ...
def eagle(): ...
def astronaut(): ...
def brick(): ...
def grass(): ...
def gravel(): ...
def text(): ...
def checkerboard(): ...
def cells3d(): ...
def human_mitosis(): ...
def cell(): ...
def coins(): ...
def kidney(): ...
def lily(): ...
def logo(): ...
def microaneurysms(): ...
def moon(): ...
def page(): ...
def horse(): ...
def clock(): ...
def immunohistochemistry(): ...
def chelsea(): ...

# Define an alias for chelsea that is more descriptive.
cat = ...

def coffee(): ...
def hubble_deep_field(): ...
def retina(): ...
def shepp_logan_phantom(): ...
def colorwheel(): ...
def rocket(): ...
def stereo_motorcycle(): ...
def lfw_subset(): ...
def skin(): ...
def nickel_solidification(): ...
def protein_transport(): ...
def brain(): ...
def vortex(): ...
