# Python: 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# Library: scipy, version: 1.6.2
# Module: scipy.spatial._hausdorff, version: unspecified
import typing
import builtins as _mod_builtins

__all__: list
__doc__: str
__file__: str
__name__: str
__package__: str
def __pyx_unpickle_Enum() -> typing.Any:
    ...

__test__: dict
def directed_hausdorff() -> typing.Any:
    ...

def __getattr__(name) -> typing.Any:
    ...

