"""
This type stub file was generated by pyright.
"""

"""Global IPython app to support test running.

We must start our own ipython object and heavily muck with it so that all the
modifications IPython makes to system behavior don't send the doctest machinery
into a fit.  This code should be considered a gross hack, but it gets the job
done.
"""
def get_ipython(): # -> None:
    ...

def xsys(self, cmd): # -> None:
    """Replace the default system call with a capturing one for doctest.
    """
    ...

def start_ipython(): # -> None:
    """Start a global IPython shell, which we need for IPython-specific syntax.
    """
    ...

