# Python: 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# Library: scipy, version: 1.6.2
# Module: scipy._lib._test_ccallback, version: unspecified
import typing
import builtins as _mod_builtins

__doc__: typing.Any
__file__: str
__name__: str
__package__: str
def test_call_nodata() -> typing.Any:
    ...

def test_call_nonlocal() -> typing.Any:
    ...

def test_call_simple() -> typing.Any:
    ...

def test_get_data_capsule() -> typing.Any:
    ...

def test_get_plus1_capsule() -> typing.Any:
    ...

def test_get_plus1b_capsule() -> typing.Any:
    ...

def test_get_plus1bc_capsule() -> typing.Any:
    ...

def __getattr__(name) -> typing.Any:
    ...

