
import numpy as np

def mean_change(arr_1: np.ndarray, arr_2: np.ndarray) -> float:
    """Calculate the mean difference between two arrays.

    Equivalent to np.abs(arr_1 - arr2).mean().
    """
    ...

def psi(x: float) -> float: ...

