# -*- coding: utf-8 -*-
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.
# Based on the quaternion class in the visvis project.

import numpy as np

class Quaternion(object):
    def __init__(self, w=1, x=0, y=0, z=0, normalize=True): ...
    def __repr__(self): ...
    def copy(self): ...
    def norm(self): ...
    def _normalize(self): ...
    def normalize(self): ...
    def conjugate(self): ...
    def inverse(self): ...
    def exp(self): ...
    def log(self): ...
    def __add__(self, q): ...
    def __sub__(self, q): ...
    def __mul__(self, q2): ...
    def rotate_point(self, p): ...
    def get_matrix(self): ...
    def get_axis_angle(self): ...
    @classmethod
    def create_from_axis_angle(cls, angle, ax, ay, az, degrees=False): ...
    @classmethod
    def create_from_euler_angles(cls, rx, ry, rz, degrees=False): ...
