# -*- coding: utf-8 -*-
# This file was auto-generated from `mc_meta/LookUpTable.h` by
# `mc_meta/createluts.py`.

# static const char casesClassic[256][16]
CASESCLASSIC = ...

# static const char cases[256][2]
CASES = ...

# static const char tiling1[16][3]
TILING1 = ...

# static const char tiling2[24][6]
TILING2 = ...

# static const char tiling3_1[24][6]
TILING3_1 = ...

# static const char tiling3_2[24][12]
TILING3_2 = ...

# static const char tiling4_1[8][6]
TILING4_1 = ...

# static const char tiling4_2[8][18]
TILING4_2 = ...

# static const char tiling5[48][9]
TILING5 = ...

# static const char tiling6_1_1[48][9]
TILING6_1_1 = ...

# static const char tiling6_1_2[48][27]
TILING6_1_2 = ...

# static const char tiling6_2[48][15]
TILING6_2 = ...

# static const char tiling7_1[16][9]
TILING7_1 = ...

# static const char tiling7_2[16][3][15]
TILING7_2 = ...

# static const char tiling7_3[16][3][27]
TILING7_3 = ...

# static const char tiling7_4_1[16][15]
TILING7_4_1 = ...

# static const char tiling7_4_2[16][27]
TILING7_4_2 = ...

# static const char tiling8[6][6]
TILING8 = ...

# static const char tiling9[8][12]
TILING9 = ...

# static const char tiling10_1_1[6][12]
TILING10_1_1 = ...

# static const char tiling10_1_1_[6][12]
TILING10_1_1_ = ...

# static const char tiling10_1_2[6][24]
TILING10_1_2 = ...

# static const char tiling10_2[6][24]
TILING10_2 = ...

# static const char tiling10_2_[6][24]
TILING10_2_ = ...

# static const char tiling11[12][12]
TILING11 = ...

# static const char tiling12_1_1[24][12]
TILING12_1_1 = ...

# static const char tiling12_1_1_[24][12]
TILING12_1_1_ = ...

# static const char tiling12_1_2[24][24]
TILING12_1_2 = ...

# static const char tiling12_2[24][24]
TILING12_2 = ...

# static const char tiling12_2_[24][24]
TILING12_2_ = ...

# static const char tiling13_1[2][12]
TILING13_1 = ...

# static const char tiling13_1_[2][12]
TILING13_1_ = ...

# static const char tiling13_2[2][6][18]
TILING13_2 = ...

# static const char tiling13_2_[2][6][18]
TILING13_2_ = ...

# static const char tiling13_3[2][12][30]
TILING13_3 = ...

# static const char tiling13_3_[2][12][30]
TILING13_3_ = ...

# static const char tiling13_4[2][4][36]
TILING13_4 = ...

# static const char tiling13_5_1[2][4][18]
TILING13_5_1 = ...

# static const char tiling13_5_2[2][4][30]
TILING13_5_2 = ...

# static const char tiling14[12][12]
TILING14 = ...

# static const char test3[24]
TEST3 = ...

# static const char test4[8]
TEST4 = ...

# static const char test6[48][3]
TEST6 = ...

# static const char test7[16][5]
TEST7 = ...

# static const char test10[6][3]
TEST10 = ...

# static const char test12[24][4]
TEST12 = ...

# static const char test13[2][7]
TEST13 = ...

# static const char subconfig13[64]
SUBCONFIG13 = ...
