from typing import Sequence

def dayofweek(y: int, m: int, d: int) -> int: ...
def is_leapyear(year: int) -> bool: ...
def get_days_in_month(year: int, month: int) -> int: ...
def get_week_of_year(year: int, month: int, day: int) -> int: ...

# cpdef iso_calendar_t get_iso_calendar(int year, int month, int day) nogil
def get_day_of_year(year: int, month: int, day: int) -> int: ...
def get_lastbday(year: int, month: int) -> int: ...
def get_firstbday(year: int, month: int) -> int: ...

DAY_NANOS: int = ...
HOUR_NANOS: int = ...
month_offset: Sequence[int] = ...
