# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.
# -----------------------------------------------------------------------------

import os.path as op

# List the vispy fonts made available online
_vispy_fonts = ...

def _get_vispy_font_filename(face, bold, italic): ...
