from numpy.distutils.misc_util import Configuration
from numpy.distutils.core import setup
import numpy
import os
import platform


def configuration(parent_package: str = "", top_path=None):
    ...
