name: "publish"
on:
  workflow_dispatch: {}
  release:
    types:
      - "published"
      - "released"

jobs:
  publish:
    runs-on: "{{ actions_runner }}"
    steps:
      - uses: "blakeNaccarato/copier-python-workflow-setup@v0.1.0"
        with:
          python-version: "{{ python_version }}"
      - run: "flit publish"
        env:
          FLIT_USERNAME: "__token__"
          FLIT_PASSWORD: "{% raw %}${{ secrets.PYPI_TOKEN }}{% endraw %}"
