"""
This type stub file was generated by pyright.
"""

import pytest

def pytest_collection_modifyitems(items): # -> None:
    """This function is automatically run by pytest passing all collected test
    functions.

    We use it to add asyncio marker to all async tests and assert we don't use
    test functions that are async generators which wouldn't make sense.
    """
    ...

def get_ipython():
    ...

@pytest.fixture(scope='session', autouse=True)
def work_path():
    ...

def nopage(strng, start=..., screen_lines=..., pager_cmd=...): # -> None:
    ...

def xsys(self, cmd): # -> None:
    """Replace the default system call with a capturing one for doctest.
    """
    ...

def inject(): # -> None:
    ...

