from vispy.util.svg.shapes import Rect
import numpy as np

class Rect(object):
    def __init__(self, *args, **kwargs): ...
    @property
    def pos(self): ...
    @pos.setter
    def pos(self, p): ...
    @property
    def size(self): ...
    @size.setter
    def size(self, s): ...
    @property
    def width(self): ...
    @width.setter
    def width(self, w): ...
    @property
    def height(self): ...
    @height.setter
    def height(self, h): ...
    @property
    def left(self): ...
    @left.setter
    def left(self, x): ...
    @property
    def right(self): ...
    @right.setter
    def right(self, x): ...
    @property
    def bottom(self): ...
    @bottom.setter
    def bottom(self, y): ...
    @property
    def top(self): ...
    @top.setter
    def top(self, y): ...
    @property
    def center(self): ...
    @center.setter
    def center(self, value): ...
    def padded(self, padding: float) -> Rect: ...
    def normalized(self): ...
    def flipped(self, x: bool = False, y: bool = True) -> Rect: ...
    def __eq__(self, r): ...
    def __add__(self, a): ...
    def contains(self, x: float, y: float) -> bool: ...
    def __repr__(self): ...
    def _transform_in(self): ...
    def _transform_out(self, coords): ...
