# Stubs for django.db.migrations (Python 3.6)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from .migration import Migration as Migration
from .migration import swappable_dependency as swappable_dependency

# FIXME: Add all operations here
from .operations import *  # noqa:F403
