import numpy as np
from scipy.spatial import distance

def _ensure_spacing(coord, spacing, p_norm, max_out): ...
def ensure_spacing(
    coords,
    spacing: float = 1,
    p_norm: float = ...,
    min_split_size: int = 50,
    max_out: int | None = None,
    *,
    max_split_size: int = 2000
): ...
