"""
This type stub file was generated by pyright.
"""

from typing import List

"""Find the path to LightGBM dynamic library files."""
def find_lib_path() -> List[str]:
    """Find the path to LightGBM library files.

    Returns
    -------
    lib_path: list of str
       List of all found library paths to LightGBM.
    """
    ...

