name: "CodeQL"

on:
  schedule:
    - cron: "38 16 * * 4"

jobs:
  analyze:
    name: "Analyze"
    runs-on: "{{ actions_runner }}"

    strategy:
      fail-fast: false
      matrix:
        language: ["python"]

    steps:
      - name: "Checkout repository"
        uses: "actions/checkout@v3.5.3"
      - name: "Initialize CodeQL"
        uses: "github/codeql-action/init@v2.21.2"
        with:
          languages: "{% raw %}${{ matrix.language }}{% endraw %}"
      - name: "Autobuild"
        uses: "github/codeql-action/autobuild@v2.21.2"
      - name: "Perform CodeQL Analysis"
        uses: "github/codeql-action/analyze@v2.21.2"
        with:
          category: "{% raw %}/language:${{matrix.language}}{% endraw %}"
