
import numpy as np


def min_pos(X: np.ndarray) -> float:
    """Find the minimum value of an array over positive values
    Returns the maximum representable value of the input dtype if none of the
    values are positive.
    """
    ...



def cholesky_delete(L: np.ndarray, go_out: int) -> None: ...
