"""
This type stub file was generated by pyright.
"""

"""Release data for the IPython project."""
_version_major = ...
_version_minor = ...
_version_patch = ...
_version_extra = ...
_version_extra = ...
_ver = ...
__version__ = ...
if _version_extra:
    __version__ = ...
version = ...
version_info = ...
kernel_protocol_version_info = ...
kernel_protocol_version = ...
license = ...
authors = ...
author = ...
author_email = ...
