"""
This type stub file was generated by pyright.
"""

from IPython.core.debugger import Pdb

PTK3 = ...
_use_simple_prompt = ...
class TerminalPdb(Pdb):
    """Standalone IPython debugger."""
    def __init__(self, *args, pt_session_options=..., **kwargs) -> None:
        ...
    
    def pt_init(self, pt_session_options=...): # -> None:
        """Initialize the prompt session and the prompt loop
        and store them in self.pt_app and self.pt_loop.

        Additional keyword arguments for the PromptSession class
        can be specified in pt_session_options.
        """
        ...
    
    def cmdloop(self, intro=...): # -> None:
        """Repeatedly issue a prompt, accept input, parse an initial prefix
        off the received input, and dispatch to action methods, passing them
        the remainder of the line as argument.

        override the same methods from cmd.Cmd to provide prompt toolkit replacement.
        """
        ...
    
    def do_interact(self, arg): # -> None:
        ...
    


def set_trace(frame=...): # -> None:
    """
    Start debugging from `frame`.

    If frame is not specified, debugging starts from caller's frame.
    """
    ...

if __name__ == '__main__':
    old_trace_dispatch = ...
