from .base import clone as clone
from ._config import (
    get_config as get_config,
    set_config as set_config,
    config_context as config_context,
)
from .utils._show_versions import show_versions as show_versions
import sys as sys
import logging as logging
import os as os
import random as random

logger = ...


# PEP0440 compatible formatted version, see:
# https://www.python.org/dev/peps/pep-0440/
#
# Generic release markers:
#   X.Y.0   # For first release after an increment in Y
#   X.Y.Z   # For bugfix releases
#
# Admissible pre-release markers:
#   X.Y.ZaN   # Alpha release
#   X.Y.ZbN   # Beta release
#   X.Y.ZrcN  # Release Candidate
#   X.Y.Z     # Final release
#
# Dev branch marker is: 'X.Y.dev' or 'X.Y.devN' where N is an integer.
# 'X.Y.dev0' is the canonical version of 'X.Y.dev'
#
__version__: str = ...


def setup_module(module):
    ...
