from numpy.distutils.misc_util import Configuration
from numpy.distutils.core import setup

# Author: Alexandre Gramfort <alexandre.gramfort@inria.fr>
# License: BSD 3 clause
import os

import numpy


def configuration(parent_package: str = "", top_path=None):
    ...
