from ..classes.multidigraph import MultiDiGraph
import networkx
from ..utils import open_file
from ..classes.graph import Graph

def write_p2g(G: Graph, path, encoding="utf-8"): ...
def read_p2g(path, encoding="utf-8") -> MultiDiGraph: ...
def parse_p2g(lines) -> MultiDiGraph: ...
