from ...classes.graph import Graph
from ...utils.decorators import not_implemented_for

__all__ = [
    "number_strongly_connected_components",
    "strongly_connected_components",
    "is_strongly_connected",
    "strongly_connected_components_recursive",
    "kosaraju_strongly_connected_components",
    "condensation",
]

def strongly_connected_components(G: Graph): ...
def kosaraju_strongly_connected_components(G: Graph, source=None): ...
def strongly_connected_components_recursive(G: Graph): ...
def number_strongly_connected_components(G: Graph): ...
def is_strongly_connected(G: Graph) -> bool: ...
def condensation(G: Graph, scc=None): ...
