from functools import reduce
import numpy as np
from ..draw import polygon
from .._shared.version_requirements import require

LEFT_CLICK: int = ...
RIGHT_CLICK: int = ...

def _mask_from_vertices(vertices, shape, label): ...
@require("matplotlib", ">=3.0.3")
def _draw_polygon(ax, vertices, alpha=0.4): ...
@require("matplotlib", ">=3.0.3")
def manual_polygon_segmentation(
    image, alpha: float = 0.4, return_all: bool = False
): ...
@require("matplotlib", ">=3.0.3")
def manual_lasso_segmentation(image, alpha: float = 0.4, return_all: bool = False): ...
