from typing import Any

from django.db import models

class Redirect(models.Model):
    site: models.ForeignKey[Any] = ...
    old_path: models.CharField[Any] = ...
    new_path: models.CharField[Any] = ...
