"""
This type stub file was generated by pyright.
"""

"""Sentinel class for constants with useful reprs"""
class Sentinel:
    def __init__(self, name, module, docstring=...) -> None:
        ...
    
    def __repr__(self):
        ...
    


