def parse_date_time(date_col, time_col): ...
def parse_date_fields(year_col, month_col, day_col): ...
def parse_all_fields(
    year_col, month_col, day_col, hour_col, minute_col, second_col
): ...
def generic_parser(parse_func, *cols): ...
