"""
This type stub file was generated by pyright.
"""

from IPython.core.magic import Magics, line_magic, magics_class

"""Implementation of magic functions for the extension machinery.
"""
@magics_class
class ExtensionMagics(Magics):
    """Magics to manage the IPython extensions system."""
    @line_magic
    def load_ext(self, module_str): # -> None:
        """Load an IPython extension by its module name."""
        ...
    
    @line_magic
    def unload_ext(self, module_str): # -> None:
        """Unload an IPython extension by its module name.

        Not all extensions can be unloaded, only those which define an
        ``unload_ipython_extension`` function.
        """
        ...
    
    @line_magic
    def reload_ext(self, module_str): # -> None:
        """Reload an IPython extension by its module name."""
        ...
    


