# Python: 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# Library: scipy, version: 1.6.2
# Module: scipy._lib._uarray._uarray, version: unspecified
import typing
import builtins as _mod_builtins
import uarray as _mod_uarray

BackendNotImplementedError = _mod_uarray.BackendNotImplementedError
_Function = _mod_uarray._Function
_SetBackendContext = _mod_uarray._SetBackendContext
_SkipBackendContext = _mod_uarray._SkipBackendContext
__doc__: typing.Any
__file__: str
__name__: str
__package__: str
def clear_all_globals() -> typing.Any:
    ...

def clear_backends() -> typing.Any:
    ...

def register_backend() -> typing.Any:
    ...

def set_global_backend() -> typing.Any:
    ...

def __getattr__(name) -> typing.Any:
    ...

