# -*- coding: utf-8 -*-
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.

from __future__ import division
from ... import gloo

class Compiler(object):
    def __init__(self, namespace=None, **shaders): ...
    def __getitem__(self, item): ...
    def compile(self, pretty: bool = True): ...
    def _rename_objects_fast(self): ...
    def _rename_objects_pretty(self): ...
    def _is_global(self, obj): ...
    def _name_available(self, obj, name, shaders): ...
    def _assign_name(self, obj, name, shaders): ...
