from collections.abc import Iterable

import warnings

from ..classes.graph import Graph
from ..utils import open_file

__all__ = ["read_pajek", "parse_pajek", "generate_pajek", "write_pajek"]

def generate_pajek(G: Graph): ...
def write_pajek(G: Graph, path, encoding="UTF-8"): ...
def read_pajek(path, encoding="UTF-8"): ...
def parse_pajek(lines: str | Iterable): ...
def make_qstr(t): ...
