# Python: 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# Library: scipy, version: 1.6.2
# Module: scipy.special.cython_special, version: unspecified
import typing
import builtins as _mod_builtins

__doc__: str
__file__: str
__name__: str
__package__: str
__pyx_capi__: dict
__test__: dict
def _airy_pywrap(x0) -> typing.Any:
    ...

def _airye_pywrap(x0) -> typing.Any:
    ...

def _bench_airy_D_cy() -> typing.Any:
    ...

def _bench_airy_D_py() -> typing.Any:
    ...

def _bench_airy_d_cy() -> typing.Any:
    ...

def _bench_airy_d_py() -> typing.Any:
    ...

def _bench_beta_dd_cy() -> typing.Any:
    ...

def _bench_beta_dd_py() -> typing.Any:
    ...

def _bench_erf_D_cy() -> typing.Any:
    ...

def _bench_erf_D_py() -> typing.Any:
    ...

def _bench_erf_d_cy() -> typing.Any:
    ...

def _bench_erf_d_py() -> typing.Any:
    ...

def _bench_exprel_d_cy() -> typing.Any:
    ...

def _bench_exprel_d_py() -> typing.Any:
    ...

def _bench_gamma_D_cy() -> typing.Any:
    ...

def _bench_gamma_D_py() -> typing.Any:
    ...

def _bench_gamma_d_cy() -> typing.Any:
    ...

def _bench_gamma_d_py() -> typing.Any:
    ...

def _bench_jv_dD_cy() -> typing.Any:
    ...

def _bench_jv_dD_py() -> typing.Any:
    ...

def _bench_jv_dd_cy() -> typing.Any:
    ...

def _bench_jv_dd_py() -> typing.Any:
    ...

def _bench_loggamma_D_cy() -> typing.Any:
    ...

def _bench_loggamma_D_py() -> typing.Any:
    ...

def _bench_logit_d_cy() -> typing.Any:
    ...

def _bench_logit_d_py() -> typing.Any:
    ...

def _bench_psi_D_cy() -> typing.Any:
    ...

def _bench_psi_D_py() -> typing.Any:
    ...

def _bench_psi_d_cy() -> typing.Any:
    ...

def _bench_psi_d_py() -> typing.Any:
    ...

def _ellipj_pywrap() -> typing.Any:
    ...

def _fresnel_pywrap(x0) -> typing.Any:
    ...

def _it2i0k0_pywrap() -> typing.Any:
    ...

def _it2j0y0_pywrap() -> typing.Any:
    ...

def _itairy_pywrap() -> typing.Any:
    ...

def _iti0k0_pywrap() -> typing.Any:
    ...

def _itj0y0_pywrap() -> typing.Any:
    ...

def _kelvin_pywrap() -> typing.Any:
    ...

def _mathieu_cem_pywrap() -> typing.Any:
    ...

def _mathieu_modcem1_pywrap() -> typing.Any:
    ...

def _mathieu_modcem2_pywrap() -> typing.Any:
    ...

def _mathieu_modsem1_pywrap() -> typing.Any:
    ...

def _mathieu_modsem2_pywrap() -> typing.Any:
    ...

def _mathieu_sem_pywrap() -> typing.Any:
    ...

def _modfresnelm_pywrap() -> typing.Any:
    ...

def _modfresnelp_pywrap() -> typing.Any:
    ...

def _obl_ang1_cv_pywrap() -> typing.Any:
    ...

def _obl_ang1_pywrap() -> typing.Any:
    ...

def _obl_rad1_cv_pywrap() -> typing.Any:
    ...

def _obl_rad1_pywrap() -> typing.Any:
    ...

def _obl_rad2_cv_pywrap() -> typing.Any:
    ...

def _obl_rad2_pywrap() -> typing.Any:
    ...

def _pbdv_pywrap() -> typing.Any:
    ...

def _pbvv_pywrap() -> typing.Any:
    ...

def _pbwa_pywrap() -> typing.Any:
    ...

def _pro_ang1_cv_pywrap() -> typing.Any:
    ...

def _pro_ang1_pywrap() -> typing.Any:
    ...

def _pro_rad1_cv_pywrap() -> typing.Any:
    ...

def _pro_rad1_pywrap() -> typing.Any:
    ...

def _pro_rad2_cv_pywrap() -> typing.Any:
    ...

def _pro_rad2_pywrap() -> typing.Any:
    ...

def _shichi_pywrap(x0) -> typing.Any:
    ...

def _sici_pywrap(x0) -> typing.Any:
    ...

def agm() -> typing.Any:
    'See the documentation for scipy.special.agm'
    ...

def bdtr(x0, x1, x2) -> typing.Any:
    'See the documentation for scipy.special.bdtr'
    ...

def bdtrc(x0, x1, x2) -> typing.Any:
    'See the documentation for scipy.special.bdtrc'
    ...

def bdtri(x0, x1, x2) -> typing.Any:
    'See the documentation for scipy.special.bdtri'
    ...

def bdtrik() -> typing.Any:
    'See the documentation for scipy.special.bdtrik'
    ...

def bdtrin() -> typing.Any:
    'See the documentation for scipy.special.bdtrin'
    ...

def bei() -> typing.Any:
    'See the documentation for scipy.special.bei'
    ...

def beip() -> typing.Any:
    'See the documentation for scipy.special.beip'
    ...

def ber() -> typing.Any:
    'See the documentation for scipy.special.ber'
    ...

def berp() -> typing.Any:
    'See the documentation for scipy.special.berp'
    ...

def besselpoly() -> typing.Any:
    'See the documentation for scipy.special.besselpoly'
    ...

def beta() -> typing.Any:
    'See the documentation for scipy.special.beta'
    ...

def betainc() -> typing.Any:
    'See the documentation for scipy.special.betainc'
    ...

def betaincinv() -> typing.Any:
    'See the documentation for scipy.special.betaincinv'
    ...

def betaln() -> typing.Any:
    'See the documentation for scipy.special.betaln'
    ...

def binom() -> typing.Any:
    'See the documentation for scipy.special.binom'
    ...

def boxcox() -> typing.Any:
    'See the documentation for scipy.special.boxcox'
    ...

def boxcox1p() -> typing.Any:
    'See the documentation for scipy.special.boxcox1p'
    ...

def btdtr() -> typing.Any:
    'See the documentation for scipy.special.btdtr'
    ...

def btdtri() -> typing.Any:
    'See the documentation for scipy.special.btdtri'
    ...

def btdtria() -> typing.Any:
    'See the documentation for scipy.special.btdtria'
    ...

def btdtrib() -> typing.Any:
    'See the documentation for scipy.special.btdtrib'
    ...

def cbrt() -> typing.Any:
    'See the documentation for scipy.special.cbrt'
    ...

def chdtr() -> typing.Any:
    'See the documentation for scipy.special.chdtr'
    ...

def chdtrc() -> typing.Any:
    'See the documentation for scipy.special.chdtrc'
    ...

def chdtri() -> typing.Any:
    'See the documentation for scipy.special.chdtri'
    ...

def chdtriv() -> typing.Any:
    'See the documentation for scipy.special.chdtriv'
    ...

def chndtr() -> typing.Any:
    'See the documentation for scipy.special.chndtr'
    ...

def chndtridf() -> typing.Any:
    'See the documentation for scipy.special.chndtridf'
    ...

def chndtrinc() -> typing.Any:
    'See the documentation for scipy.special.chndtrinc'
    ...

def chndtrix() -> typing.Any:
    'See the documentation for scipy.special.chndtrix'
    ...

def cosdg() -> typing.Any:
    'See the documentation for scipy.special.cosdg'
    ...

def cosm1() -> typing.Any:
    'See the documentation for scipy.special.cosm1'
    ...

def cotdg() -> typing.Any:
    'See the documentation for scipy.special.cotdg'
    ...

def dawsn(x0) -> typing.Any:
    'See the documentation for scipy.special.dawsn'
    ...

def ellipe() -> typing.Any:
    'See the documentation for scipy.special.ellipe'
    ...

def ellipeinc() -> typing.Any:
    'See the documentation for scipy.special.ellipeinc'
    ...

def ellipk() -> typing.Any:
    'See the documentation for scipy.special.ellipk'
    ...

def ellipkinc() -> typing.Any:
    'See the documentation for scipy.special.ellipkinc'
    ...

def ellipkm1() -> typing.Any:
    'See the documentation for scipy.special.ellipkm1'
    ...

def entr() -> typing.Any:
    'See the documentation for scipy.special.entr'
    ...

def erf(x0) -> typing.Any:
    'See the documentation for scipy.special.erf'
    ...

def erfc(x0) -> typing.Any:
    'See the documentation for scipy.special.erfc'
    ...

def erfcinv() -> typing.Any:
    'See the documentation for scipy.special.erfcinv'
    ...

def erfcx(x0) -> typing.Any:
    'See the documentation for scipy.special.erfcx'
    ...

def erfi(x0) -> typing.Any:
    'See the documentation for scipy.special.erfi'
    ...

def erfinv() -> typing.Any:
    'See the documentation for scipy.special.erfinv'
    ...

def eval_chebyc(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.eval_chebyc'
    ...

def eval_chebys(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.eval_chebys'
    ...

def eval_chebyt(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.eval_chebyt'
    ...

def eval_chebyu(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.eval_chebyu'
    ...

def eval_gegenbauer(x0, x1, x2) -> typing.Any:
    'See the documentation for scipy.special.eval_gegenbauer'
    ...

def eval_genlaguerre(x0, x1, x2) -> typing.Any:
    'See the documentation for scipy.special.eval_genlaguerre'
    ...

def eval_hermite() -> typing.Any:
    'See the documentation for scipy.special.eval_hermite'
    ...

def eval_hermitenorm() -> typing.Any:
    'See the documentation for scipy.special.eval_hermitenorm'
    ...

def eval_jacobi(x0, x1, x2, x3) -> typing.Any:
    'See the documentation for scipy.special.eval_jacobi'
    ...

def eval_laguerre(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.eval_laguerre'
    ...

def eval_legendre(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.eval_legendre'
    ...

def eval_sh_chebyt(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.eval_sh_chebyt'
    ...

def eval_sh_chebyu(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.eval_sh_chebyu'
    ...

def eval_sh_jacobi(x0, x1, x2, x3) -> typing.Any:
    'See the documentation for scipy.special.eval_sh_jacobi'
    ...

def eval_sh_legendre(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.eval_sh_legendre'
    ...

def exp1(x0) -> typing.Any:
    'See the documentation for scipy.special.exp1'
    ...

def exp10() -> typing.Any:
    'See the documentation for scipy.special.exp10'
    ...

def exp2() -> typing.Any:
    'See the documentation for scipy.special.exp2'
    ...

def expi(x0) -> typing.Any:
    'See the documentation for scipy.special.expi'
    ...

def expit(x0) -> typing.Any:
    'See the documentation for scipy.special.expit'
    ...

def expm1(x0) -> typing.Any:
    'See the documentation for scipy.special.expm1'
    ...

def expn(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.expn'
    ...

def exprel() -> typing.Any:
    'See the documentation for scipy.special.exprel'
    ...

def fdtr() -> typing.Any:
    'See the documentation for scipy.special.fdtr'
    ...

def fdtrc() -> typing.Any:
    'See the documentation for scipy.special.fdtrc'
    ...

def fdtri() -> typing.Any:
    'See the documentation for scipy.special.fdtri'
    ...

def fdtridfd() -> typing.Any:
    'See the documentation for scipy.special.fdtridfd'
    ...

def gamma(x0) -> typing.Any:
    'See the documentation for scipy.special.gamma'
    ...

def gammainc() -> typing.Any:
    'See the documentation for scipy.special.gammainc'
    ...

def gammaincc() -> typing.Any:
    'See the documentation for scipy.special.gammaincc'
    ...

def gammainccinv() -> typing.Any:
    'See the documentation for scipy.special.gammainccinv'
    ...

def gammaincinv() -> typing.Any:
    'See the documentation for scipy.special.gammaincinv'
    ...

def gammaln() -> typing.Any:
    'See the documentation for scipy.special.gammaln'
    ...

def gammasgn() -> typing.Any:
    'See the documentation for scipy.special.gammasgn'
    ...

def gdtr() -> typing.Any:
    'See the documentation for scipy.special.gdtr'
    ...

def gdtrc() -> typing.Any:
    'See the documentation for scipy.special.gdtrc'
    ...

def gdtria() -> typing.Any:
    'See the documentation for scipy.special.gdtria'
    ...

def gdtrib() -> typing.Any:
    'See the documentation for scipy.special.gdtrib'
    ...

def gdtrix() -> typing.Any:
    'See the documentation for scipy.special.gdtrix'
    ...

def hankel1() -> typing.Any:
    'See the documentation for scipy.special.hankel1'
    ...

def hankel1e() -> typing.Any:
    'See the documentation for scipy.special.hankel1e'
    ...

def hankel2() -> typing.Any:
    'See the documentation for scipy.special.hankel2'
    ...

def hankel2e() -> typing.Any:
    'See the documentation for scipy.special.hankel2e'
    ...

def huber() -> typing.Any:
    'See the documentation for scipy.special.huber'
    ...

def hyp0f1(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.hyp0f1'
    ...

def hyp1f1(x0, x1, x2) -> typing.Any:
    'See the documentation for scipy.special.hyp1f1'
    ...

def hyp2f1(x0, x1, x2, x3) -> typing.Any:
    'See the documentation for scipy.special.hyp2f1'
    ...

def hyperu() -> typing.Any:
    'See the documentation for scipy.special.hyperu'
    ...

def i0() -> typing.Any:
    'See the documentation for scipy.special.i0'
    ...

def i0e() -> typing.Any:
    'See the documentation for scipy.special.i0e'
    ...

def i1() -> typing.Any:
    'See the documentation for scipy.special.i1'
    ...

def i1e() -> typing.Any:
    'See the documentation for scipy.special.i1e'
    ...

def inv_boxcox() -> typing.Any:
    'See the documentation for scipy.special.inv_boxcox'
    ...

def inv_boxcox1p() -> typing.Any:
    'See the documentation for scipy.special.inv_boxcox1p'
    ...

def it2struve0() -> typing.Any:
    'See the documentation for scipy.special.it2struve0'
    ...

def itmodstruve0() -> typing.Any:
    'See the documentation for scipy.special.itmodstruve0'
    ...

def itstruve0() -> typing.Any:
    'See the documentation for scipy.special.itstruve0'
    ...

def iv(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.iv'
    ...

def ive(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.ive'
    ...

def j0() -> typing.Any:
    'See the documentation for scipy.special.j0'
    ...

def j1() -> typing.Any:
    'See the documentation for scipy.special.j1'
    ...

def jv(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.jv'
    ...

def jve(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.jve'
    ...

def k0() -> typing.Any:
    'See the documentation for scipy.special.k0'
    ...

def k0e() -> typing.Any:
    'See the documentation for scipy.special.k0e'
    ...

def k1() -> typing.Any:
    'See the documentation for scipy.special.k1'
    ...

def k1e() -> typing.Any:
    'See the documentation for scipy.special.k1e'
    ...

def kei() -> typing.Any:
    'See the documentation for scipy.special.kei'
    ...

def keip() -> typing.Any:
    'See the documentation for scipy.special.keip'
    ...

def ker() -> typing.Any:
    'See the documentation for scipy.special.ker'
    ...

def kerp() -> typing.Any:
    'See the documentation for scipy.special.kerp'
    ...

def kl_div() -> typing.Any:
    'See the documentation for scipy.special.kl_div'
    ...

def kn(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.kn'
    ...

def kolmogi() -> typing.Any:
    'See the documentation for scipy.special.kolmogi'
    ...

def kolmogorov() -> typing.Any:
    'See the documentation for scipy.special.kolmogorov'
    ...

def kv(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.kv'
    ...

def kve(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.kve'
    ...

def log1p(x0) -> typing.Any:
    'See the documentation for scipy.special.log1p'
    ...

def log_ndtr(x0) -> typing.Any:
    'See the documentation for scipy.special.log_ndtr'
    ...

def loggamma(x0) -> typing.Any:
    'See the documentation for scipy.special.loggamma'
    ...

def logit(x0) -> typing.Any:
    'See the documentation for scipy.special.logit'
    ...

def lpmv() -> typing.Any:
    'See the documentation for scipy.special.lpmv'
    ...

def mathieu_a() -> typing.Any:
    'See the documentation for scipy.special.mathieu_a'
    ...

def mathieu_b() -> typing.Any:
    'See the documentation for scipy.special.mathieu_b'
    ...

def modstruve() -> typing.Any:
    'See the documentation for scipy.special.modstruve'
    ...

def nbdtr(x0, x1, x2) -> typing.Any:
    'See the documentation for scipy.special.nbdtr'
    ...

def nbdtrc(x0, x1, x2) -> typing.Any:
    'See the documentation for scipy.special.nbdtrc'
    ...

def nbdtri(x0, x1, x2) -> typing.Any:
    'See the documentation for scipy.special.nbdtri'
    ...

def nbdtrik() -> typing.Any:
    'See the documentation for scipy.special.nbdtrik'
    ...

def nbdtrin() -> typing.Any:
    'See the documentation for scipy.special.nbdtrin'
    ...

def ncfdtr() -> typing.Any:
    'See the documentation for scipy.special.ncfdtr'
    ...

def ncfdtri() -> typing.Any:
    'See the documentation for scipy.special.ncfdtri'
    ...

def ncfdtridfd() -> typing.Any:
    'See the documentation for scipy.special.ncfdtridfd'
    ...

def ncfdtridfn() -> typing.Any:
    'See the documentation for scipy.special.ncfdtridfn'
    ...

def ncfdtrinc() -> typing.Any:
    'See the documentation for scipy.special.ncfdtrinc'
    ...

def nctdtr() -> typing.Any:
    'See the documentation for scipy.special.nctdtr'
    ...

def nctdtridf() -> typing.Any:
    'See the documentation for scipy.special.nctdtridf'
    ...

def nctdtrinc() -> typing.Any:
    'See the documentation for scipy.special.nctdtrinc'
    ...

def nctdtrit() -> typing.Any:
    'See the documentation for scipy.special.nctdtrit'
    ...

def ndtr(x0) -> typing.Any:
    'See the documentation for scipy.special.ndtr'
    ...

def ndtri() -> typing.Any:
    'See the documentation for scipy.special.ndtri'
    ...

def nrdtrimn() -> typing.Any:
    'See the documentation for scipy.special.nrdtrimn'
    ...

def nrdtrisd() -> typing.Any:
    'See the documentation for scipy.special.nrdtrisd'
    ...

def obl_cv() -> typing.Any:
    'See the documentation for scipy.special.obl_cv'
    ...

def owens_t() -> typing.Any:
    'See the documentation for scipy.special.owens_t'
    ...

def pdtr() -> typing.Any:
    'See the documentation for scipy.special.pdtr'
    ...

def pdtrc() -> typing.Any:
    'See the documentation for scipy.special.pdtrc'
    ...

def pdtri(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.pdtri'
    ...

def pdtrik() -> typing.Any:
    'See the documentation for scipy.special.pdtrik'
    ...

def poch() -> typing.Any:
    'See the documentation for scipy.special.poch'
    ...

def pro_cv() -> typing.Any:
    'See the documentation for scipy.special.pro_cv'
    ...

def pseudo_huber() -> typing.Any:
    'See the documentation for scipy.special.pseudo_huber'
    ...

def psi(x0) -> typing.Any:
    'See the documentation for scipy.special.psi'
    ...

def radian() -> typing.Any:
    'See the documentation for scipy.special.radian'
    ...

def rel_entr() -> typing.Any:
    'See the documentation for scipy.special.rel_entr'
    ...

def rgamma(x0) -> typing.Any:
    'See the documentation for scipy.special.rgamma'
    ...

def round() -> typing.Any:
    'See the documentation for scipy.special.round'
    ...

def sindg() -> typing.Any:
    'See the documentation for scipy.special.sindg'
    ...

def smirnov(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.smirnov'
    ...

def smirnovi(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.smirnovi'
    ...

def spence(x0) -> typing.Any:
    'See the documentation for scipy.special.spence'
    ...

def sph_harm(x0, x1, x2, x3) -> typing.Any:
    'See the documentation for scipy.special.sph_harm'
    ...

def spherical_in() -> typing.Any:
    'See the documentation for scipy.special.spherical_in'
    ...

def spherical_jn() -> typing.Any:
    'See the documentation for scipy.special.spherical_jn'
    ...

def spherical_kn() -> typing.Any:
    'See the documentation for scipy.special.spherical_kn'
    ...

def spherical_yn() -> typing.Any:
    'See the documentation for scipy.special.spherical_yn'
    ...

def stdtr() -> typing.Any:
    'See the documentation for scipy.special.stdtr'
    ...

def stdtridf() -> typing.Any:
    'See the documentation for scipy.special.stdtridf'
    ...

def stdtrit() -> typing.Any:
    'See the documentation for scipy.special.stdtrit'
    ...

def struve() -> typing.Any:
    'See the documentation for scipy.special.struve'
    ...

def tandg() -> typing.Any:
    'See the documentation for scipy.special.tandg'
    ...

def tklmbda() -> typing.Any:
    'See the documentation for scipy.special.tklmbda'
    ...

def voigt_profile() -> typing.Any:
    'See the documentation for scipy.special.voigt_profile'
    ...

def wofz() -> typing.Any:
    'See the documentation for scipy.special.wofz'
    ...

def wrightomega(x0) -> typing.Any:
    'See the documentation for scipy.special.wrightomega'
    ...

def xlog1py(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.xlog1py'
    ...

def xlogy(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.xlogy'
    ...

def y0() -> typing.Any:
    'See the documentation for scipy.special.y0'
    ...

def y1() -> typing.Any:
    'See the documentation for scipy.special.y1'
    ...

def yn(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.yn'
    ...

def yv(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.yv'
    ...

def yve(x0, x1) -> typing.Any:
    'See the documentation for scipy.special.yve'
    ...

def zetac() -> typing.Any:
    'See the documentation for scipy.special.zetac'
    ...

def __getattr__(name) -> typing.Any:
    ...

