# Python: 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# Library: scipy, version: 1.6.2
# Module: scipy._lib._fpumode, version: unspecified
import typing
import builtins as _mod_builtins

__doc__: typing.Any
__file__: str
__name__: str
__package__: str
def get_fpu_mode() -> typing.Any:
    'get_fpu_mode()\n\nGet the current FPU control word, in a platform-dependent format.\nReturns None if not implemented on current platform.'
    ...

def __getattr__(name) -> typing.Any:
    ...

