# -*- coding: utf-8 -*-
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.

from .axis import AxisVisual as AxisVisual  # noqa
from .box import BoxVisual as BoxVisual  # noqa
from .cube import CubeVisual as CubeVisual  # noqa
from .ellipse import EllipseVisual as EllipseVisual  # noqa
from .gridlines import GridLinesVisual as GridLinesVisual  # noqa
from .image import ImageVisual as ImageVisual  # noqa
from .image_complex import ComplexImageVisual as ComplexImageVisual  # noqa
from .gridmesh import GridMeshVisual as GridMeshVisual  # noqa
from .histogram import HistogramVisual as HistogramVisual  # noqa
from .infinite_line import InfiniteLineVisual as InfiniteLineVisual  # noqa
from .isocurve import IsocurveVisual as IsocurveVisual  # noqa
from .isoline import IsolineVisual as IsolineVisual  # noqa
from .isosurface import IsosurfaceVisual as IsosurfaceVisual  # noqa
from .line import LineVisual as LineVisual, ArrowVisual as ArrowVisual  # noqa
from .linear_region import LinearRegionVisual as LinearRegionVisual  # noqa
from .line_plot import LinePlotVisual as LinePlotVisual  # noqa
from .markers import MarkersVisual as MarkersVisual  # noqa
from .mesh import MeshVisual as MeshVisual  # noqa
from .mesh_normals import MeshNormalsVisual as MeshNormalsVisual  # noqa
from .plane import PlaneVisual as PlaneVisual  # noqa
from .polygon import PolygonVisual as PolygonVisual  # noqa
from .rectangle import RectangleVisual as RectangleVisual  # noqa
from .regular_polygon import RegularPolygonVisual as RegularPolygonVisual  # noqa
from .scrolling_lines import ScrollingLinesVisual as ScrollingLinesVisual  # noqa
from .spectrogram import SpectrogramVisual as SpectrogramVisual  # noqa
from .sphere import SphereVisual as SphereVisual  # noqa
from .surface_plot import SurfacePlotVisual as SurfacePlotVisual  # noqa
from .text import TextVisual as TextVisual  # noqa
from .tube import TubeVisual as TubeVisual  # noqa
from .visual import (
    BaseVisual as BaseVisual,
    Visual as Visual,
    CompoundVisual as CompoundVisual,
)  # noqa
from .volume import VolumeVisual as VolumeVisual  # noqa
from .xyz_axis import XYZAxisVisual as XYZAxisVisual  # noqa
from .border import _BorderVisual as _BorderVisual  # noqa
from .colorbar import ColorBarVisual as ColorBarVisual  # noqa
from .graphs import GraphVisual as GraphVisual  # noqa
from .windbarb import WindbarbVisual as WindbarbVisual  # noqa
