from ..classes.graph import Graph

__all__ = ["is_isolate", "isolates", "number_of_isolates"]

def is_isolate(G: Graph, n) -> bool: ...
def isolates(G: Graph): ...
def number_of_isolates(G: Graph) -> int: ...
