# -*- coding: utf-8 -*-
# -----------------------------------------------------------------------------
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.
# -----------------------------------------------------------------------------

from .path_collection import PathCollection as PathCollection  # noqa
from .point_collection import PointCollection as PointCollection  # noqa
from .polygon_collection import PolygonCollection as PolygonCollection  # noqa
from .segment_collection import SegmentCollection as SegmentCollection  # noqa
from .triangle_collection import TriangleCollection as TriangleCollection  # noqa
