# Python: 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# Library: scipy, version: 1.6.2
# Module: scipy.special._test_round, version: unspecified
import typing
import builtins as _mod_builtins

__doc__: typing.Any
__file__: str
__name__: str
__package__: str
def __pyx_unpickle_Enum() -> typing.Any:
    ...

__test__: dict
def assert_(val, msg) -> typing.Any:
    '\n    Assert that works in release mode.\n    Accepts callable msg to allow deferring evaluation until failure.\n\n    The Python built-in ``assert`` does not work when executing code in\n    optimized mode (the ``-O`` flag) - no byte-code is generated for it.\n\n    For documentation on usage, refer to the Python documentation.\n\n    '
    ...

def have_fenv() -> typing.Any:
    ...

def random_double() -> typing.Any:
    ...

def test_add_round() -> typing.Any:
    ...

def __getattr__(name) -> typing.Any:
    ...

