__version__: str = ...

submodules: list = ...

from ._shared.version_requirements import ensure_python_version as ensure_python_version

from ._shared import lazy as lazy

__getattr__, __lazy_dir__, _ = ...

def __dir__(): ...

# Logic for checking for improper install and importing while in the source
# tree when package has not been installed inplace.
# Code adapted from scikit-learn's __check_build module.
_INPLACE_MSG: str = ...

_STANDARD_MSG: str = ...

def _raise_build_error(e): ...

from skimage._shared.tester import PytestTester as PytestTester  # noqa

test = ...
