"""
This type stub file was generated by pyright.
"""

import datatable
from pandas import concat
from pandas.api.types import is_sparse as is_dtype_sparse
from dask import delayed
from dask.array import from_delayed as dask_array_from_delayed
from dask.bag import from_delayed as dask_bag_from_delayed
from dask.distributed import default_client, wait

"""Compatibility library."""
PANDAS_INSTALLED = ...
PANDAS_INSTALLED = ...
class pd_Series:
    """Dummy class for pandas.Series."""
    ...


class pd_DataFrame:
    """Dummy class for pandas.DataFrame."""
    ...


concat = ...
is_dtype_sparse = ...
MATPLOTLIB_INSTALLED = ...
MATPLOTLIB_INSTALLED = ...
GRAPHVIZ_INSTALLED = ...
GRAPHVIZ_INSTALLED = ...
if hasattr(datatable, "Frame"):
    dt_DataTable = ...
else:
    dt_DataTable = ...
DATATABLE_INSTALLED = ...
DATATABLE_INSTALLED = ...
class dt_DataTable:
    """Dummy class for datatable.DataTable."""
    ...


SKLEARN_INSTALLED = ...
_LGBMModelBase = ...
_LGBMRegressorBase = ...
_LGBMClassifierBase = ...
_LGBMLabelEncoder = ...
LGBMNotFittedError = ...
_LGBMStratifiedKFold = ...
_LGBMGroupKFold = ...
_LGBMCheckXY = ...
_LGBMCheckArray = ...
_LGBMCheckSampleWeight = ...
_LGBMAssertAllFinite = ...
_LGBMCheckClassificationTargets = ...
_LGBMComputeSampleWeight = ...
SKLEARN_INSTALLED = ...
class _LGBMModelBase:
    """Dummy class for sklearn.base.BaseEstimator."""
    ...


class _LGBMClassifierBase:
    """Dummy class for sklearn.base.ClassifierMixin."""
    ...


class _LGBMRegressorBase:
    """Dummy class for sklearn.base.RegressorMixin."""
    ...


_LGBMLabelEncoder = ...
LGBMNotFittedError = ...
_LGBMStratifiedKFold = ...
_LGBMGroupKFold = ...
_LGBMCheckXY = ...
_LGBMCheckArray = ...
_LGBMCheckSampleWeight = ...
_LGBMAssertAllFinite = ...
_LGBMCheckClassificationTargets = ...
_LGBMComputeSampleWeight = ...
DASK_INSTALLED = ...
DASK_INSTALLED = ...
dask_array_from_delayed = ...
dask_bag_from_delayed = ...
delayed = ...
default_client = ...
wait = ...
class Client:
    """Dummy class for dask.distributed.Client."""
    ...


class dask_Array:
    """Dummy class for dask.array.Array."""
    ...


class dask_DataFrame:
    """Dummy class for dask.dataframe.DataFrame."""
    ...


class dask_Series:
    """Dummy class for dask.dataframe.Series."""
    ...


