# Python: 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# Library: scipy, version: 1.6.2
# Module: scipy.ndimage._nd_image, version: unspecified
import typing
import builtins as _mod_builtins

__doc__: typing.Any
__file__: str
__name__: str
__package__: str
def binary_erosion() -> typing.Any:
    ...

def binary_erosion2() -> typing.Any:
    ...

def correlate() -> typing.Any:
    ...

def correlate1d() -> typing.Any:
    ...

def distance_transform_bf() -> typing.Any:
    ...

def distance_transform_op() -> typing.Any:
    ...

def euclidean_feature_transform() -> typing.Any:
    ...

def find_objects() -> typing.Any:
    ...

def fourier_filter() -> typing.Any:
    ...

def fourier_shift() -> typing.Any:
    ...

def generic_filter() -> typing.Any:
    ...

def generic_filter1d() -> typing.Any:
    ...

def geometric_transform() -> typing.Any:
    ...

def min_or_max_filter() -> typing.Any:
    ...

def min_or_max_filter1d() -> typing.Any:
    ...

def rank_filter() -> typing.Any:
    ...

def spline_filter1d() -> typing.Any:
    ...

def uniform_filter1d() -> typing.Any:
    ...

def watershed_ift() -> typing.Any:
    ...

def zoom_shift() -> typing.Any:
    ...

def __getattr__(name) -> typing.Any:
    ...

