from ..classes.graph import Graph
from ..utils import not_implemented_for

__all__ = ["mycielskian", "mycielski_graph"]

def mycielskian(G: Graph, iterations: int = 1): ...
def mycielski_graph(n: int): ...
