"""
This type stub file was generated by pyright.
"""

from IPython.core.magic import Magics, line_magic, magics_class

"""Implementation of packaging-related magic functions.
"""
CONDA_COMMANDS_REQUIRING_PREFIX = ...
CONDA_COMMANDS_REQUIRING_YES = ...
CONDA_ENV_FLAGS = ...
CONDA_YES_FLAGS = ...
@magics_class
class PackagingMagics(Magics):
    """Magics related to packaging & installation"""
    @line_magic
    def pip(self, line): # -> None:
        """Run the pip package manager within the current kernel.

        Usage:
          %pip install [pkgs]
        """
        ...
    
    @line_magic
    def conda(self, line): # -> None:
        """Run the conda package manager within the current kernel.

        Usage:
          %conda install [pkgs]
        """
        ...
    


