# Python: 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# Library: scipy, version: 1.6.2
# Module: scipy.optimize._highs._highs_constants, version: unspecified
import typing
import builtins as _mod_builtins

CONST_INF: float
CONST_I_INF: int
HIGHS_SIMPLEX_CRASH_STRATEGY_BIXBY: int
HIGHS_SIMPLEX_CRASH_STRATEGY_LTSF: int
HIGHS_SIMPLEX_CRASH_STRATEGY_OFF: int
HIGHS_SIMPLEX_DUAL_EDGE_WEIGHT_STRATEGY_DANTZIG: int
HIGHS_SIMPLEX_DUAL_EDGE_WEIGHT_STRATEGY_DEVEX: int
HIGHS_SIMPLEX_DUAL_EDGE_WEIGHT_STRATEGY_STEEPEST_EDGE: int
HIGHS_SIMPLEX_DUAL_EDGE_WEIGHT_STRATEGY_STEEPEST_EDGE_TO_DEVEX_SWITCH: int
HIGHS_SIMPLEX_PRIMAL_EDGE_WEIGHT_STRATEGY_DANTZIG: int
HIGHS_SIMPLEX_PRIMAL_EDGE_WEIGHT_STRATEGY_DEVEX: int
HIGHS_SIMPLEX_STRATEGY_CHOOSE: int
HIGHS_SIMPLEX_STRATEGY_DUAL: int
HIGHS_SIMPLEX_STRATEGY_PRIMAL: int
MESSAGE_LEVEL_ALWAYS: int
MESSAGE_LEVEL_DETAILED: int
MESSAGE_LEVEL_MINIMAL: int
MESSAGE_LEVEL_NONE: int
MESSAGE_LEVEL_VERBOSE: int
MODEL_STATUS_LOAD_ERROR: int
MODEL_STATUS_MODEL_EMPTY: int
MODEL_STATUS_MODEL_ERROR: int
MODEL_STATUS_NOTSET: int
MODEL_STATUS_OPTIMAL: int
MODEL_STATUS_POSTSOLVE_ERROR: int
MODEL_STATUS_PRESOLVE_ERROR: int
MODEL_STATUS_PRIMAL_INFEASIBLE: int
MODEL_STATUS_PRIMAL_UNBOUNDED: int
MODEL_STATUS_REACHED_DUAL_OBJECTIVE_VALUE_UPPER_BOUND: int
MODEL_STATUS_REACHED_ITERATION_LIMIT: int
MODEL_STATUS_REACHED_TIME_LIMIT: int
MODEL_STATUS_SOLVE_ERROR: int
__doc__: str
__file__: str
__name__: str
__package__: str
__test__: dict
def __getattr__(name) -> typing.Any:
    ...

