# Python: 3.8.2 (tags/v3.8.2:7b3ab59, Feb 25 2020, 23:03:10) [MSC v.1916 64 bit (AMD64)]
# Library: scipy, version: 1.6.2
# Module: scipy.spatial._distance_wrap, version: unspecified
import typing
import builtins as _mod_builtins

__doc__: typing.Any
__file__: str
__name__: str
__package__: str
def cdist_braycurtis_double_wrap() -> typing.Any:
    ...

def cdist_canberra_double_wrap() -> typing.Any:
    ...

def cdist_chebyshev_double_wrap() -> typing.Any:
    ...

def cdist_cityblock_double_wrap() -> typing.Any:
    ...

def cdist_correlation_double_wrap(XA, XB, dm, **kwargs) -> typing.Any:
    ...

def cdist_cosine_double_wrap() -> typing.Any:
    ...

def cdist_dice_bool_wrap() -> typing.Any:
    ...

def cdist_euclidean_double_wrap() -> typing.Any:
    ...

def cdist_hamming_bool_wrap() -> typing.Any:
    ...

def cdist_hamming_double_wrap() -> typing.Any:
    ...

def cdist_jaccard_bool_wrap() -> typing.Any:
    ...

def cdist_jaccard_double_wrap() -> typing.Any:
    ...

def cdist_jensenshannon_double_wrap() -> typing.Any:
    ...

def cdist_kulsinski_bool_wrap() -> typing.Any:
    ...

def cdist_mahalanobis_double_wrap() -> typing.Any:
    ...

def cdist_minkowski_double_wrap() -> typing.Any:
    ...

def cdist_old_weighted_minkowski_double_wrap() -> typing.Any:
    ...

def cdist_rogerstanimoto_bool_wrap() -> typing.Any:
    ...

def cdist_russellrao_bool_wrap() -> typing.Any:
    ...

def cdist_seuclidean_double_wrap() -> typing.Any:
    ...

def cdist_sokalmichener_bool_wrap() -> typing.Any:
    ...

def cdist_sokalsneath_bool_wrap() -> typing.Any:
    ...

def cdist_sqeuclidean_double_wrap() -> typing.Any:
    ...

def cdist_weighted_chebyshev_double_wrap() -> typing.Any:
    ...

def cdist_weighted_minkowski_double_wrap() -> typing.Any:
    ...

def cdist_yule_bool_wrap() -> typing.Any:
    ...

def pdist_braycurtis_double_wrap() -> typing.Any:
    ...

def pdist_canberra_double_wrap() -> typing.Any:
    ...

def pdist_chebyshev_double_wrap() -> typing.Any:
    ...

def pdist_cityblock_double_wrap() -> typing.Any:
    ...

def pdist_correlation_double_wrap(X, dm, **kwargs) -> typing.Any:
    ...

def pdist_cosine_double_wrap() -> typing.Any:
    ...

def pdist_dice_bool_wrap() -> typing.Any:
    ...

def pdist_euclidean_double_wrap() -> typing.Any:
    ...

def pdist_hamming_bool_wrap() -> typing.Any:
    ...

def pdist_hamming_double_wrap() -> typing.Any:
    ...

def pdist_jaccard_bool_wrap() -> typing.Any:
    ...

def pdist_jaccard_double_wrap() -> typing.Any:
    ...

def pdist_jensenshannon_double_wrap() -> typing.Any:
    ...

def pdist_kulsinski_bool_wrap() -> typing.Any:
    ...

def pdist_mahalanobis_double_wrap() -> typing.Any:
    ...

def pdist_minkowski_double_wrap() -> typing.Any:
    ...

def pdist_old_weighted_minkowski_double_wrap() -> typing.Any:
    ...

def pdist_rogerstanimoto_bool_wrap() -> typing.Any:
    ...

def pdist_russellrao_bool_wrap() -> typing.Any:
    ...

def pdist_seuclidean_double_wrap() -> typing.Any:
    ...

def pdist_sokalmichener_bool_wrap() -> typing.Any:
    ...

def pdist_sokalsneath_bool_wrap() -> typing.Any:
    ...

def pdist_sqeuclidean_double_wrap() -> typing.Any:
    ...

def pdist_weighted_chebyshev_double_wrap() -> typing.Any:
    ...

def pdist_weighted_minkowski_double_wrap() -> typing.Any:
    ...

def pdist_yule_bool_wrap() -> typing.Any:
    ...

def to_squareform_from_vector_wrap() -> typing.Any:
    ...

def to_vector_from_squareform_wrap() -> typing.Any:
    ...

def __getattr__(name) -> typing.Any:
    ...

