from ..utils.multiclass import type_of_target as type_of_target
from itertools import combinations as combinations
from ..utils import (
    check_array as check_array,
    check_consistent_length as check_consistent_length,
)

import numpy as np
