"""
This type stub file was generated by pyright.
"""

"""Simple function to call to get the current InteractiveShell instance
"""
def get_ipython(): # -> None:
    """Get the global InteractiveShell instance.

    Returns None if no InteractiveShell instance is registered.
    """
    ...

