"""
This type stub file was generated by pyright.
"""

"""cli-specific implementation of process utilities.

cli - Common Language Infrastructure for IronPython. Code
      can run on any operating system. Check os.name for os-
      specific settings.

This file is only meant to be imported by process.py, not by end-users.

This file is largely untested. To become a full drop-in process
interface for IronPython will probably require you to help fill
in the details. 
"""
def system(cmd): # -> None:
    """
    system(cmd) should work in a cli environment on Mac OSX, Linux,
    and Windows
    """
    ...

def getoutput(cmd):
    """
    getoutput(cmd) should work in a cli environment on Mac OSX, Linux,
    and Windows
    """
    ...

def check_pid(pid):
    """
    Check if a process with the given PID (pid) exists
    """
    ...

