from typing import Callable

def safe_import(mod_name: str, min_version: str | None = ...): ...
def skip_if_installed(package: str) -> Callable: ...
def skip_if_no(package: str, min_version: str | None = ...) -> Callable: ...

skip_if_no_mpl = ...
skip_if_mpl = ...
skip_if_32bit = ...
skip_if_windows = ...
skip_if_has_locale = ...
skip_if_not_us_locale = ...
skip_if_no_scipy = ...
skip_if_no_ne = ...

def skip_if_np_lt(
    ver_str: str, reason: str | None = ..., *args, **kwds
) -> Callable: ...
def parametrize_fixture_doc(*args): ...
def check_file_leaks(func) -> Callable: ...
def async_mark(): ...
