from typing import Any

from django.contrib.gis.gdal.base import GDALBase as GDALBase

class DataSource(GDALBase):
    destructor: Any = ...
    encoding: Any = ...
    ptr: Any = ...
    driver: Any = ...
    def __init__(
        self,
        ds_input: Any,
        ds_driver: bool = ...,
        write: bool = ...,
        encoding: str = ...,
    ) -> None: ...
    def __getitem__(self, index: Any) -> Any: ...
    def __len__(self) -> Any: ...
    @property
    def layer_count(self) -> Any: ...
    @property
    def name(self) -> Any: ...
