import sys
import warnings

import pytest

import networkx

def pytest_addoption(parser): ...
def pytest_configure(config): ...
def pytest_collection_modifyitems(config, items): ...

# TODO: The warnings below need to be dealt with, but for now we silence them.
@pytest.fixture(autouse=True)
def set_warnings(): ...
@pytest.fixture(autouse=True)
def add_nx(doctest_namespace): ...

# List of files that pytest should ignore

collect_ignore: list = ...

needs_numpy: list = ...
needs_scipy: list = ...
needs_matplotlib: list = ...
needs_pandas: list = ...
needs_yaml: list = ...
needs_pygraphviz: list = ...
needs_pydot: list = ...
needs_ogr: list = ...
needs_sympy: list = ...
