# -*- coding: utf-8 -*-
# Copyright (c) Vispy Development Team. All Rights Reserved.
# Distributed under the (new) BSD License. See LICENSE.txt for more info.

# Class adapted from mne-python

class SimpleBunch(dict):
    def __init__(self, **kwargs): ...
